@@ -104,7 +104,7 @@ static const char *GETOPT_OPTIONS =
     "y:"
 #endif
 #ifdef WITH_TLS
-    "Y:"
+    "Y:J:"
 #endif    
     "zZ";
 
@@ -188,6 +188,7 @@ static struct option long_options[] = {
 # endif
 # ifdef WITH_TLS
     { "tls", 1, NULL, 'Y' },
+    { "tlsciphersuite", 1, NULL, 'J' },
 # endif
     { "allowdotfiles", 0, NULL, 'z' },
     { "customerproof", 0, NULL, 'Z' },
@@ -295,7 +296,6 @@ typedef struct DLHandler_ {
     int f;
     void *tls_fd;
     off_t file_size;
-    size_t min_dlmap_size;
     size_t dlmap_size;
     off_t cur_pos;
     off_t chunk_size;    
