@@ -12,7 +12,7 @@
 static char *ldap_host;
 static char *port_s;
 static int port;
-static char *root;
+static char *binddn;
 static char *pwd;
 static char *base;
 static char *ldap_filter;
@@ -25,11 +25,14 @@ static char *default_gid_s;
 static gid_t default_gid;
 static char *use_tls_s;
 static int use_tls;
+static char *ldap_auth_method_s;
+static int use_ldap_bind_method;
+static char *ldap_default_home_directory;
 
 static ConfigKeywords ldap_config_keywords[] = {
     { "LDAPServer", &ldap_host },
     { "LDAPPort", &port_s },    
-    { "LDAPBindDN", &root },        
+    { "LDAPBindDN", &binddn },        
     { "LDAPBindPW", &pwd },
     { "LDAPBaseDN", &base },
     { "LDAPFilter", &ldap_filter},
@@ -38,6 +41,8 @@ static ConfigKeywords ldap_config_keywords[] = {
     { "LDAPDefaultUID", &default_uid_s },
     { "LDAPDefaultGID", &default_gid_s },
     { "LDAPUseTLS", &use_tls_s },
+    { "LDAPAuthMethod", &ldap_auth_method_s },
+    { "LDAPDefaultHomeDirectory", &ldap_default_home_directory },
     { NULL, NULL }
 };
 
