@@ -8,6 +8,7 @@
 # include "log_mysql.h"
 # include "messages.h"
 # include "crypto.h"
+# include "alt_arc4random.h"
 
 # ifdef WITH_DMALLOC
 #  include <dmalloc.h>
@@ -24,8 +25,8 @@ static int pw_mysql_validate_name(const char *name)
             (*name >= '0' && *name <= '9') ||
             *name == ' ' || *name == '-' ||
             *name == '_' || *name == '\'' || *name == '.' ||
-            *name == ':' || *name == '@') {
-            /* God bless the Perl 'unless' keyword */
+            *name == ':' || *name == '@' || *name == '+') {
+            /* God bless the Ruby 'unless' keyword */
         } else {
             return -1;
         }            
@@ -195,11 +196,11 @@ static int pw_mysql_connect(MYSQL ** const id_sql_server)
     if ((*id_sql_server = mysql_init(NULL)) == NULL) {
         down:
         if (server_down == 0) {
-	    const char *mysql_err = "mysql_init()";
-	    
-	    if (*id_sql_server != NULL) {
-		mysql_err = mysql_error(*id_sql_server);
-	    }
+            const char *mysql_err = "mysql_init()";
+            
+            if (*id_sql_server != NULL) {
+                mysql_err = mysql_error(*id_sql_server);
+            }
             server_down++;
             logfile(LOG_ERR, MSG_SQL_DOWN " [%s]", mysql_err);
         }
@@ -208,11 +209,11 @@ static int pw_mysql_connect(MYSQL ** const id_sql_server)
     if (mysql_real_connect(*id_sql_server, server, user, pw,
                            db, port, socket_path,
 #ifdef CLIENT_MULTI_STATEMENTS
-			   CLIENT_MULTI_STATEMENTS
+                           CLIENT_MULTI_STATEMENTS
 #else
-			   0
+                           0
 #endif
-			   ) == NULL) {
+                           ) == NULL) {
         goto down;
     }
     if (mysql_ping(*id_sql_server) != 0) {
@@ -283,12 +284,12 @@ static char *pw_mysql_getquery(MYSQL * const id_sql_server,
     
     bye:
     if (qresult != NULL) {
-	mysql_free_result(qresult);
+        mysql_free_result(qresult);
 #ifdef CLIENT_MULTI_STATEMENTS
-	while (mysql_next_result(id_sql_server) == 0) {
-	    qresult = mysql_store_result(id_sql_server);
-	    mysql_free_result(qresult);
-	}
+        while (mysql_next_result(id_sql_server) == 0) {
+            qresult = mysql_store_result(id_sql_server);
+            mysql_free_result(qresult);
+        }
 #endif
     }    
     return answer;    
@@ -322,7 +323,8 @@ void pw_mysql_check(AuthResult * const result,
     char *escaped_peer_ip = NULL;
     char *escaped_decimal_ip = NULL;    
     int committed = 1;
-    int crypto_crypt = 0, crypto_mysql = 0, crypto_md5 = 0, crypto_plain = 0;
+    int crypto_crypt = 0, crypto_mysql = 0, crypto_md5 = 0, crypto_sha1 = 0,
+        crypto_plain = 0;
     unsigned long decimal_ip_num = 0UL;
     char decimal_ip[42];
     char hbuf[NI_MAXHOST];
@@ -416,12 +418,15 @@ void pw_mysql_check(AuthResult * const result,
         crypto_crypt++;
         crypto_mysql++;
         crypto_md5++;
+        crypto_sha1++;
     } else if (strcasecmp(crypto, PASSWD_SQL_CRYPT) == 0) {
         crypto_crypt++;
     } else if (strcasecmp(crypto, PASSWD_SQL_MYSQL) == 0) {
         crypto_mysql++;
     } else if (strcasecmp(crypto, PASSWD_SQL_MD5) == 0) {
         crypto_md5++;
+    } else if (strcasecmp(crypto, PASSWD_SQL_SHA1) == 0) {
+        crypto_sha1++;
     } else {                           /* default to plaintext */
         crypto_plain++;
     }
@@ -441,17 +446,22 @@ void pw_mysql_check(AuthResult * const result,
 # if MYSQL_VERSION_ID < 40100
         hash_password(hash_res, password);
 # else
-        hash_password(hash_res, password, strlen(password));	    
-# endif	    
+        hash_password(hash_res, password, strlen(password));        
+# endif     
         snprintf(scrambled_password, sizeof scrambled_password, "%08lx%08lx", 
                  hash_res[0], hash_res[1]);
 #else
-	char scrambled_password[42]; /* 2 * 20 (sha1 hash size) + 2 */
+        char scrambled_password[42]; /* 2 * 20 (sha1 hash size) + 2 */
 
 # if MYSQL_VERSION_ID >= 40100 && MYSQL_VERSION_ID < 40101
-	make_scrambled_password(scrambled_password, password, 1, NULL);
+        make_scrambled_password(scrambled_password, password, 1, NULL);
 # else
-	make_scrambled_password(scrambled_password, password);
+#  ifdef HAVE_MY_MAKE_SCRAMBLED_PASSWORD
+        my_make_scrambled_password(scrambled_password, password,
+                                   strlen(password));
+#  else
+        make_scrambled_password(scrambled_password, password);
+#  endif
 # endif
 #endif
         if (strcmp(scrambled_password, spwd) == 0) {
@@ -465,7 +475,15 @@ void pw_mysql_check(AuthResult * const result,
             strcmp(crypted, spwd) == 0) {
             goto auth_ok;
         }
-    }    
+    }
+    if (crypto_sha1 != 0) {
+        const char *crypted;
+
+        if ((crypted = (const char *) crypto_hash_sha1(password, 1)) != NULL &&
+            strcmp(crypted, spwd) == 0) {
+            goto auth_ok;
+        }
+    }
     if (crypto_plain != 0) {
         if (*password != 0 &&    /* refuse null cleartext passwords */
             strcmp(password, spwd) == 0) {
