@@ -1,3 +1,4 @@
+#define MSG_TLS_CIPHER_FAILED "SSL/TLS: Invalid TLSCipherSuite specified '%s'"
 #define MSG_TIMEOUT "Timeout"
 #define MSG_CAPABILITIES "Kan ikke ndre muligheder"
 #define MSG_CLIENT_CLOSED_CNX "Klient afbrd forbindelsen"
@@ -87,7 +88,7 @@
 #define MSG_ANON_CANT_DELETE "Anonyme brugere kan ikke slette filer"
 #define MSG_ANON_CANT_OVERWRITE "Anonyme brugere m ikke overskive filer"
 #define MSG_DELE_FAILED "Kunne ikke slette %s"
-#define MSG_DELE_SUCCESS "Slettede %s"
+#define MSG_DELE_SUCCESS "Slettede %s%s%s%s"
 #define MSG_DELE_TOTAL_FAILURE "Ingen fil slettet"
 #define MSG_LOAD_TOO_HIGH \
     "Belastningen var %3.2f da du kom p. Vi tillader ikke anonyme brugere\n" \
@@ -172,7 +173,7 @@
 #define MSG_NEW_CONNECTION "Ny forbindelse fra %s"
 #define MSG_WELCOME_TO "Velkommen til"
 #define MSG_MAX_USERS "%lu brugere (det maksimale) er allerede logget p, desvrre"
-#define MSG_NB_USERS "Du er bruger nr %d af %d tilladte"
+#define MSG_NB_USERS "Du er bruger nr %u af %u tilladte"
 #define MSG_WELCOME_TIME "Lokal tid er nu %02d:%02d. Server port: %u."
 #define MSG_ANONYMOUS_FTP_ONLY "Kun anonym FTP er tilladt her"
 #define MSG_RATIOS_EVERYONE "FORHOLD ER SLET TIL FOR ALLE :"
