@@ -1,3 +1,4 @@
+#define MSG_TLS_CIPHER_FAILED "SSL/TLS: Invalid TLSCipherSuite specified '%s'"
 #define MSG_TIMEOUT "Timeout"
 #define MSG_CAPABILITIES "Unable to switch capabilities"
 #define MSG_CLIENT_CLOSED_CNX "Client closed the connection"
@@ -87,7 +88,7 @@
 #define MSG_ANON_CANT_DELETE "Anonymous users can not delete files"
 #define MSG_ANON_CANT_OVERWRITE "Anonymous users may not overwrite existing files"
 #define MSG_DELE_FAILED "Could not delete %s"
-#define MSG_DELE_SUCCESS "Deleted %s"
+#define MSG_DELE_SUCCESS "Deleted %s%s%s%s"
 #define MSG_DELE_TOTAL_FAILURE "No file deleted"
 #define MSG_LOAD_TOO_HIGH \
     "The load was %3.2f when you connected. We do not allow downloads\n" \
@@ -172,7 +173,7 @@
 #define MSG_NEW_CONNECTION "New connection from %s"
 #define MSG_WELCOME_TO "Welcome to"
 #define MSG_MAX_USERS "%lu users (the maximum) are already logged in, sorry"
-#define MSG_NB_USERS "You are user number %d of %d allowed."
+#define MSG_NB_USERS "You are user number %u of %u allowed."
 #define MSG_WELCOME_TIME "Local time is now %02d:%02d. Server port: %u."
 #define MSG_ANONYMOUS_FTP_ONLY "Only anonymous FTP is allowed here"
 #define MSG_RATIOS_EVERYONE "RATIOS ARE ENABLED FOR EVERYONE:"
