@@ -173,7 +173,7 @@
 #define MSG_NEW_CONNECTION "Nueva conexin desde %s"
 #define MSG_WELCOME_TO "Bienvenido a"
 #define MSG_MAX_USERS "%lu usuarios (el mximo) estn el sistema, lo siento"
-#define MSG_NB_USERS "Eres el usuario nmero %d de %d permitidos"
+#define MSG_NB_USERS "Eres el usuario nmero %u de %u permitidos"
 #define MSG_WELCOME_TIME "La hora local es ahora %02d:%02d. Puerto del servidor: %u."
 #define MSG_ANONYMOUS_FTP_ONLY "Slo se permite FTP annimo"
 #define MSG_RATIOS_EVERYONE "LAS PROPORCIONES ESTN ESTABLECIDAS PARA TODOS :"
