@@ -1,3 +1,4 @@
+#define MSG_TLS_CIPHER_FAILED "SSL/TLS: Y a une couillasse dans ton TLSCipherSuite '%s'"
 #define MSG_TIMEOUT "Putain mais achete-toi des doigts"
 #define MSG_CAPABILITIES "Ton kernel m'a envoye chier"
 #define MSG_CLIENT_CLOSED_CNX "Le mec s'est casse"
@@ -87,7 +88,7 @@
 #define MSG_ANON_CANT_DELETE "Tu touches pas a ce putain de fichier ou je te butte"
 #define MSG_ANON_CANT_OVERWRITE "Ce fichier, il est cool, alors t'es gentil, tu touches pas"
 #define MSG_DELE_FAILED "T'as pas assez de couilles pour butter %s"
-#define MSG_DELE_SUCCESS "%s s'est fait defoncer la face"
+#define MSG_DELE_SUCCESS "%s%s%s%s s'est fait defoncer la face"
 #define MSG_DELE_TOTAL_FAILURE "Total loser"
 #define MSG_LOAD_TOO_HIGH \
     "Le serveur a une putain de charge de %3.2f .\n" \
@@ -172,7 +173,7 @@
 #define MSG_NEW_CONNECTION "%s ramene son cul"
 #define MSG_WELCOME_TO "C'est de la bonne :"
 #define MSG_MAX_USERS "%lu relous (le maximum) sont deja connectes, degage"
-#define MSG_NB_USERS "T'es le numero %d sur les %d max."
+#define MSG_NB_USERS "T'es le numero %u sur les %u max."
 #define MSG_WELCOME_TIME "L'heure locale est %02d:%02d. Port du serveur : %u."
 #define MSG_ANONYMOUS_FTP_ONLY "Je prend que les mecs anonymes"
 #define MSG_RATIOS_EVERYONE "Y A DES RATIOS POUR TOUS LES UTILISATEURS :"
