@@ -1,3 +1,4 @@
+#define MSG_TLS_CIPHER_FAILED "SSL/TLS: Invalid TLSCipherSuite specified '%s'"
 #define MSG_TIMEOUT "Timeout"
 #define MSG_CAPABILITIES "Impossibile modificare i permessi"
 #define MSG_CLIENT_CLOSED_CNX "Il client ha chiuso la connessione"
@@ -172,7 +173,7 @@
 #define MSG_NEW_CONNECTION "Nuova connessione da %s"
 #define MSG_WELCOME_TO "Benvenuto in"
 #define MSG_MAX_USERS "%lu utenti (il massimo) sono gi colleggati, spiacente"
-#define MSG_NB_USERS "Sei l'utente numero %d di %d consentiti"
+#define MSG_NB_USERS "Sei l'utente numero %u di %u consentiti"
 #define MSG_WELCOME_TIME "L'ora locale  %02d:%02d. Porta del server: %u."
 #define MSG_ANONYMOUS_FTP_ONLY "Qui  permesso solo FTP anonimo"
 #define MSG_RATIOS_EVERYONE "LE RATIOS SONO ABILITATE PER TUTTI:"
