@@ -1,3 +1,4 @@
+#define MSG_TLS_CIPHER_FAILED "SSL/TLS: Invalid TLSCipherSuite specified '%s'"
 #define MSG_TIMEOUT "ð ʰ"
 #define MSG_CAPABILITIES " ȯ Ұ"
 #define MSG_CLIENT_CLOSED_CNX "Ŭ̾Ʈ  "
@@ -87,7 +88,7 @@
 #define MSG_ANON_CANT_DELETE "Anonymous    Ҽ ϴ."
 #define MSG_ANON_CANT_OVERWRITE "Anonymous  Ⱑ Ұ մϴ."
 #define MSG_DELE_FAILED "%s  Ҽ "
-#define MSG_DELE_SUCCESS "%s "
+#define MSG_DELE_SUCCESS "%s%s%s%s "
 #define MSG_DELE_TOTAL_FAILURE "  "
 #define MSG_LOAD_TOO_HIGH \
     "ý ϰ %3.2f Դϴ.  ٿε Ұմϴ.\n" \
@@ -172,7 +173,7 @@
 #define MSG_NEW_CONNECTION "%s  ο "
 #define MSG_WELCOME_TO "!~"
 #define MSG_MAX_USERS "%lu  (ִ   ) ̹  ֽϴ. ˼մϴ."
-#define MSG_NB_USERS " %d ° Դϴ. ִ %d "
+#define MSG_NB_USERS " %u ° Դϴ. ִ %u "
 #define MSG_WELCOME_TIME " ð %02d:%02d,  Ʈ %u Դϴ."
 #define MSG_ANONYMOUS_FTP_ONLY "anonymous   մϴ."
 #define MSG_RATIOS_EVERYONE "  /ٿ   :"
