@@ -1,3 +1,4 @@
+#define MSG_TLS_CIPHER_FAILED "SSL/TLS: Invalid TLSCipherSuite specified '%s'"
 #define MSG_TIMEOUT "Onderbreking"
 #define MSG_CAPABILITIES "Onmogelijk om de instelling te wisselen"
 #define MSG_CLIENT_CLOSED_CNX "Client sloot de verbinding"
@@ -87,7 +88,7 @@
 #define MSG_ANON_CANT_DELETE "Anonieme gebruikers kunnen geen bestanden wissen"
 #define MSG_ANON_CANT_OVERWRITE "Anonieme gebruikers kunnen geen bestaande bestanden overschrijven."
 #define MSG_DELE_FAILED "Kon %s niet wissen"
-#define MSG_DELE_SUCCESS "%s gewist"
+#define MSG_DELE_SUCCESS "%s%s%s%s gewist"
 #define MSG_DELE_TOTAL_FAILURE "Geen bestand gewist"
 #define MSG_LOAD_TOO_HIGH \
     "De belasting was %3.2f toen u verbinding kreeg. Wij staan geen\n" \
@@ -172,7 +173,7 @@
 #define MSG_NEW_CONNECTION "Nieuwe verbinding vanaf %s"
 #define MSG_WELCOME_TO "Welkom bij"
 #define MSG_MAX_USERS "%lu gebruikers (het maximum) zijn reeds ingelogd, sorry"
-#define MSG_NB_USERS "U bent gebruiker nummer %d van %d toegestane gebruikers"
+#define MSG_NB_USERS "U bent gebruiker nummer %u van %u toegestane gebruikers"
 #define MSG_WELCOME_TIME "Locale tijd is nu %02d:%02d. Server poort: %u."
 #define MSG_ANONYMOUS_FTP_ONLY "Alleen anonieme FTP is hier toegestaan"
 #define MSG_RATIOS_EVERYONE "UL/DL VERHOUDINGEN ZIJN VOOR IEDEREEN INGESCHAKELD:"
@@ -205,7 +206,7 @@
 #define MSG_ILLEGAL_QUOTA "Ongeldige quota"
 #define MSG_QUOTA_FILES "%llu Bestanden in gebruik (%d%%) - goedgekeurd: %llu bestanden"
 #define MSG_QUOTA_SIZE "%llu Kbytes in gebruik (%d%%) - goedgekeurd: %llu Kb"
-#define MSG_QUOTA_EXCEEDED "Quota overschreden: %s worden niet opgeslagen"
+#define MSG_QUOTA_EXCEEDED "Quota overschreden: [%s] worden niet opgeslagen"
 #define MSG_AUTH_UNKNOWN "Onbekende autorisatie methode"
 #define MSG_PDB_BROKEN "Kan het geindexeerde  puredb bestand niet lezen (of oud formaat gedetecteerd) - Probeer pure-pw mkdb"
 #define MSG_ALIASES_ALIAS "%s is een alias voor %s."
@@ -224,3 +225,5 @@
 #define MSG_PROT_PRIVATE_NEEDED "Data connection cannot be opened with this PROT setting."
 #define MSG_PROT_UNKNOWN_LEVEL "Protection level %s not understood. Fallback to \"%s\""
 #define MSG_PROT_BEFORE_PBSZ "PROT must be preceded by a successful PBSZ command"
+#define MSG_WARN_LDAP_USERPASS_EMPTY "Geen userPassword attribuut aangetroffen. Controleer de toegangsrechten."
+#define MSG_LDAP_INVALID_AUTH_METHOD "Onjuiste LDAPAuthMethod in de configuratie. Moet 'bind' of 'password' zijn."
