@@ -1,3 +1,4 @@
+#define MSG_TLS_CIPHER_FAILED "SSL/TLS: Invalid TLSCipherSuite specified '%s'"
 #define MSG_TIMEOUT "Timeout"
 #define MSG_CAPABILITIES "Kan ikke endre egenskaper"
 #define MSG_CLIENT_CLOSED_CNX "Klienten lukket tilkoblingen"
@@ -87,7 +88,7 @@
 #define MSG_ANON_CANT_DELETE "Anonyme brukere kan ikke slette filer"
 #define MSG_ANON_CANT_OVERWRITE "Anonyme brukere kan ikke overskrive eksisterende filer"
 #define MSG_DELE_FAILED "Kunne ikke slette %s"
-#define MSG_DELE_SUCCESS "%s slettet"
+#define MSG_DELE_SUCCESS "%s%s%s%s slettet"
 #define MSG_DELE_TOTAL_FAILURE "Ingen filer slettet"
 #define MSG_LOAD_TOO_HIGH \
     "Belastningen var %3.2f nr du logget p. Vi tillater ikke anonyme brukere\n" \
@@ -172,7 +173,7 @@
 #define MSG_NEW_CONNECTION "Ny tilkobling fra %s"
 #define MSG_WELCOME_TO "Velkommen til"
 #define MSG_MAX_USERS "%lu brukere (maks) er allerede logget p"
-#define MSG_NB_USERS "Du er bruker nummer %d av %d tillatte"
+#define MSG_NB_USERS "Du er bruker nummer %u av %u tillatte"
 #define MSG_WELCOME_TIME "Den lokale tiden er n %02d:%02d. Server port: %u."
 #define MSG_ANONYMOUS_FTP_ONLY "Kun anonym FTP er tillatt her"
 #define MSG_RATIOS_EVERYONE "RATIO ER SATT P FOR ALLE:"
