@@ -1,3 +1,4 @@
+#define MSG_TLS_CIPHER_FAILED "SSL/TLS: Invalid TLSCipherSuite specified '%s'"
 #define MSG_TIMEOUT "Tempo expirado"
 #define MSG_CAPABILITIES "No foi possvel trocar capacidades"
 #define MSG_CLIENT_CLOSED_CNX "Cliente encerrou a conexo"
@@ -172,7 +173,7 @@
 #define MSG_NEW_CONNECTION "Nova conexo a partir de %s"
 #define MSG_WELCOME_TO "Bem-vindo a"
 #define MSG_MAX_USERS "%lu usurios (o mximo) j esto conectados, desculpe"
-#define MSG_NB_USERS "Voc  o usurio nmero %d de %d permitidos"
+#define MSG_NB_USERS "Voc  o usurio nmero %u de %u permitidos"
 #define MSG_WELCOME_TIME "Hora local agora  %02d:%02d. Porta do servidor: %u."
 #define MSG_ANONYMOUS_FTP_ONLY "Somente FTP annimo  permitido aqui"
 #define MSG_RATIOS_EVERYONE "PROPORES ESTO HABILITADAS PARA TODOS :"
