@@ -1,3 +1,4 @@
+#define MSG_TLS_CIPHER_FAILED "SSL/TLS: Invalid TLSCipherSuite specified '%s'"
 #define MSG_TIMEOUT "Temporizare expirata"
 #define MSG_CAPABILITIES "Nu pot comuta capabilitatile"
 #define MSG_CLIENT_CLOSED_CNX "Clientul a inchis conexiunea"
@@ -87,7 +88,7 @@
 #define MSG_ANON_CANT_DELETE "Utilizatorii anonimi nu pot sterge fisiere"
 #define MSG_ANON_CANT_OVERWRITE "Utilizatorii anonimi nu pot suprascrie fisiere existente"
 #define MSG_DELE_FAILED "Nu pot sterge %s"
-#define MSG_DELE_SUCCESS "Am sters %s"
+#define MSG_DELE_SUCCESS "Am sters %s%s%s%s"
 #define MSG_DELE_TOTAL_FAILURE "Nici un fisier selectat"
 #define MSG_LOAD_TOO_HIGH \
     "Incarcarea server-ului era %3.2f cind v-ati conectat. Nu sint permise download-uri\n" \
@@ -172,7 +173,7 @@
 #define MSG_NEW_CONNECTION "Conexiune noua de la %s"
 #define MSG_WELCOME_TO "Bine ati venit pe"
 #define MSG_MAX_USERS "%lu utilizatori (maximul) sint deja logati"
-#define MSG_NB_USERS "Sineti utilizatorul cu numarul %d din %d permisi"
+#define MSG_NB_USERS "Sineti utilizatorul cu numarul %u din %u permisi"
 #define MSG_WELCOME_TIME "Timpul local este acum %02d:%02d. Port server: %u."
 #define MSG_ANONYMOUS_FTP_ONLY "Aici este permis numai acces FTP anonim"
 #define MSG_RATIOS_EVERYONE "COTELE SINT ACTIVATE PENTRU ORICINE :"
