@@ -1,3 +1,4 @@
+#define MSG_TLS_CIPHER_FAILED "SSL/TLS: Invalid TLSCipherSuite specified '%s'"
 #define MSG_TIMEOUT "  "
 #define MSG_CAPABILITIES "   (capabilities)"
 #define MSG_CLIENT_CLOSED_CNX "  "
@@ -87,7 +88,7 @@
 #define MSG_ANON_CANT_DELETE "    "
 #define MSG_ANON_CANT_OVERWRITE "     "
 #define MSG_DELE_FAILED "  %s"
-#define MSG_DELE_SUCCESS ": %s"
+#define MSG_DELE_SUCCESS ": %s%s%s%s"
 #define MSG_DELE_TOTAL_FAILURE "    "
 #define MSG_LOAD_TOO_HIGH \
     "       %3.2f.    \n" \
@@ -172,7 +173,7 @@
 #define MSG_NEW_CONNECTION "   %s"
 #define MSG_WELCOME_TO "  "
 #define MSG_MAX_USERS "%lu  ( )  , "
-#define MSG_NB_USERS "  %d  %d "
+#define MSG_NB_USERS "  %u  %u "
 #define MSG_WELCOME_TIME "  %02d:%02d.  : %u."
 #define MSG_ANONYMOUS_FTP_ONLY "     "
 #define MSG_RATIOS_EVERYONE "    :"
