@@ -1,3 +1,4 @@
+#define MSG_TLS_CIPHER_FAILED "SSL/TLS: Invalid TLSCipherSuite specified '%s'"
 #define MSG_TIMEOUT "Timeout"
 #define MSG_CAPABILITIES "Ofrmgen att ndra mjligheter"
 #define MSG_CLIENT_CLOSED_CNX "Klienten avbrt anslutningen"
@@ -87,7 +88,7 @@
 #define MSG_ANON_CANT_DELETE "Anonyma anvndare kan inte radera filer"
 #define MSG_ANON_CANT_OVERWRITE "Anonyma anvndare kan inte skriva ver existerande filer"
 #define MSG_DELE_FAILED "Kan ej radera %s"
-#define MSG_DELE_SUCCESS "Raderade %s"
+#define MSG_DELE_SUCCESS "Raderade %s%s%s%s"
 #define MSG_DELE_TOTAL_FAILURE "Ingen fil r raderad"
 #define MSG_LOAD_TOO_HIGH \
     "Belastningen var %3.2f nr du upprttade frbindelse. Vi tillter ej nedladdningar\n" \
@@ -172,7 +173,7 @@
 #define MSG_NEW_CONNECTION "Nyanslutning frn %s"
 #define MSG_WELCOME_TO "Vlkommen till"
 #define MSG_MAX_USERS "%lu anvndare (maximala antalet) r redan inloggade"
-#define MSG_NB_USERS "Du r anvndare nummer %d av %d tilltna"
+#define MSG_NB_USERS "Du r anvndare nummer %u av %u tilltna"
 #define MSG_WELCOME_TIME "Lokal tid r nu %02d:%02d. Server port: %u."
 #define MSG_ANONYMOUS_FTP_ONLY "Endast anonym FTP r tillten"
 #define MSG_RATIOS_EVERYONE "RATIOS r aktiverat fr ALLA:"
