@@ -1,3 +1,4 @@
+#define MSG_TLS_CIPHER_FAILED "SSL/TLS: Invalid TLSCipherSuite specified '%s'"
 #define MSG_TIMEOUT "ʱ"
 #define MSG_CAPABILITIES "޷л"
 #define MSG_CLIENT_CLOSED_CNX "û˹ر"
@@ -87,7 +88,7 @@
 #define MSG_ANON_CANT_DELETE "ʹ߲ɾļ"
 #define MSG_ANON_CANT_OVERWRITE "ʹ߲ܸдִļ"
 #define MSG_DELE_FAILED "޷ɾ %s"
-#define MSG_DELE_SUCCESS "ɾ %s"
+#define MSG_DELE_SUCCESS "ɾ %s%s%s%s"
 #define MSG_DELE_TOTAL_FAILURE "ûɾļ"
 #define MSG_LOAD_TOO_HIGH "ʱ %3.2f ˸ʱǲ׼ʹء\nϴǿԵ"
 
@@ -172,7 +173,7 @@
 #define MSG_NEW_CONNECTION " %s "
 #define MSG_WELCOME_TO "ӭ"
 #define MSG_MAX_USERS "%lu ʹ(ֵ)Ѿ¼Ǹ"
-#define MSG_NB_USERS "ǵ %d ʹߣɴ %d "
+#define MSG_NB_USERS "ǵ %u ʹߣɴ %u "
 #define MSG_WELCOME_TIME "ڱʱ %02d:%02d˿ڣ %u"
 #define MSG_ANONYMOUS_FTP_ONLY "ֻFTP"
 #define MSG_RATIOS_EVERYONE "EVERYONEñ:"
