@@ -1,3 +1,4 @@
+#define MSG_TLS_CIPHER_FAILED "SSL/TLS: Invalid TLSCipherSuite specified '%s'"
 #define MSG_TIMEOUT "O"
 #define MSG_CAPABILITIES "Lkʯ"
 #define MSG_CLIENT_CLOSED_CNX "Τsu"
@@ -87,7 +88,7 @@
 #define MSG_ANON_CANT_DELETE "ΦWϥΪ̤Rɮ"
 #define MSG_ANON_CANT_OVERWRITE "ΦWϥΪ̤мg{sɮ"
 #define MSG_DELE_FAILED "LkR %s"
-#define MSG_DELE_SUCCESS "R %s"
+#define MSG_DELE_SUCCESS "R %s%s%s%s"
 #define MSG_DELE_TOTAL_FAILURE "SRɮ"
 #define MSG_LOAD_TOO_HIGH "zsuɭtO %3.2f CtpɡAڭ̤ΦWϥΪ̤UC\nWǫhOiH"
 
@@ -172,7 +173,7 @@
 #define MSG_NEW_CONNECTION " %s ssu"
 #define MSG_WELCOME_TO "wӨ"
 #define MSG_MAX_USERS "%lu ϥΪ(̤j)wgnJAp"
-#define MSG_NB_USERS "zO %d ӨϥΪ̡A̦hiF %d ӳsu"
+#define MSG_NB_USERS "zO %u ӨϥΪ̡A̦hiF %u ӳsu"
 #define MSG_WELCOME_TIME "{baɶO %02d:%02d CAf: %uC"
 #define MSG_ANONYMOUS_FTP_ONLY "o̥uΰΦWFTP"
 #define MSG_RATIOS_EVERYONE "wEVERYONEҥΤv:"
