@@ -22,8 +22,9 @@
 typedef enum PrivSepCmd_ {
     PRIVSEPCMD_NONE, 
     PRIVSEPCMD_ANSWER_ERROR, PRIVSEPCMD_ANSWER_FD,
-    PRIVSEPCMD_BINDRESPORT, PRIVSEPCMD_ANSWER_BINDRESPORT,
+    PRIVSEPCMD_BINDRESPORT, PRIVSEPCMD_ANSWER_BINDRESPORT
 #ifdef FTPWHO
+    ,
     PRIVSEPCMD_REMOVEFTPWHOENTRY, PRIVSEPCMD_ANSWER_REMOVEFTPWHOENTRY
 #endif
 } PrivSepCmd;
