@@ -2,6 +2,8 @@
 
 #include "ftpd.h"
 #include "pure-pw.h"
+#include "safe_rw.h"
+#include "alt_arc4random.h"
 #include "../puredb/src/puredb_write.h"
 #ifdef HAVE_POSIX_TERMIOS
 # include <termios.h>
@@ -179,7 +181,7 @@ static void help(void)
          "                [-q <upload ratio>] [-Q <download ratio>]\n"
          "                [-r <allow client ip>/<mask>] [-R <deny client ip>/<mask>]\n"
          "                [-i <allow local ip>/<mask>] [-I <deny local ip>/<mask>]\n"
-     "                [-y <max number of concurrent sessions>]\n"     
+         "                [-y <max number of concurrent sessions>]\n"     
          "                [-z <hhmm>-<hhmm>] [-m]\n"
          "\n"
          "pure-pw userdel <login> [-f <passwd file>] [-m]\n"
@@ -189,6 +191,7 @@ static void help(void)
          "pure-pw show    <login> [-f <passwd file>]\n"
          "\n"
          "pure-pw mkdb    [<puredb database file> [-f <passwd file>]]\n"
+         "                [-F <puredb file>]\n"
          "\n"
          "pure-pw list    [-f <passwd file>]\n"
          "\n"
@@ -211,56 +214,9 @@ static void no_mem(void)
     exit(EXIT_FAILURE);
 }
 
-#ifdef PROBE_RANDOM_AT_RUNTIME
-static void pw_zrand_probe(void)
-{
-    static const char * const devices[] = {
-        "/dev/arandom", "/dev/urandom", "/dev/random", NULL
-    };
-    const char * const *device = devices;
-    
-    do {
-        if (access(*device, F_OK | R_OK) == 0) {
-            random_device = *device;
-            break;
-        }
-        device++;
-    } while (*device != NULL);
-}
-#endif
-
 static unsigned int pw_zrand(void)
 {
-    int fd;
-    int ret;
-    
-    if (
-#ifdef PROBE_RANDOM_AT_RUNTIME
-        ((fd = open(random_device, O_RDONLY | O_NONBLOCK)) == -1)
-#elif defined(HAVE_DEV_ARANDOM)
-        ((fd = open("/dev/arandom", O_RDONLY | O_NONBLOCK)) == -1)
-#elif defined(HAVE_DEV_URANDOM)
-        ((fd = open("/dev/urandom", O_RDONLY | O_NONBLOCK)) == -1)
-#else
-        ((fd = open("/dev/random", O_RDONLY | O_NONBLOCK)) == -1)
-#endif        
-        ) {
-        nax:
-#ifdef HAVE_ARC4RANDOM
-        return (unsigned int) arc4random();
-#elif defined HAVE_RANDOM
-        return (unsigned int) random();
-#else
-        return (unsigned int) rand();
-#endif
-    }
-    if (read(fd, &ret, sizeof ret) != (ssize_t) sizeof ret) {
-        close(fd);
-        goto nax;
-    }
-    close(fd);    
-    
-    return (unsigned int) ret;
+    return (unsigned int) alt_arc4random();
 }
 
 static char *best_crypt(const char * const pwd)
@@ -802,10 +758,12 @@ static int do_useradd(const char * const file,
         fprintf(stderr, "Missing passwd file\n");
         return PW_ERROR_MISSING_PASSWD_FILE;
     }
+#ifndef ACCEPT_ROOT_VIRTUAL_USERS
     if (pwinfo.uid <= (uid_t) 0 || pwinfo.gid <= (gid_t) 0) {
         fprintf(stderr, "You must give (non-root) uid and gid\n");
         return PW_ERROR_USERADD_NOT_ROOT;
     }
+#endif
     if (pwinfo.home == NULL) {
         fprintf(stderr, "Missing home directory\n");        
         return PW_ERROR_USERADD_MISSING_HOME_DIR;
@@ -1115,7 +1073,7 @@ static int do_show(const char * const file, const PWInfo * const pwinfo)
            "Allowed client IPs : %s\n"
            "Denied  client IPs : %s\n"           
            "Time restrictions  : %04u-%04u (%s)\n"
-       "Max sim sessions   : %u (%s)\n"
+           "Max sim sessions   : %u (%s)\n"
            "\n",
            fetched_info.login,
            fetched_info.pwd,
@@ -1142,7 +1100,7 @@ static int do_show(const char * const file, const PWInfo * const pwinfo)
            SHOW_IFEN(fetched_info.has_time, fetched_info.time_begin),
            SHOW_IFEN(fetched_info.has_time, fetched_info.time_end),
            SHOW_STATE(fetched_info.has_time),
-       SHOW_IFEN(fetched_info.has_per_user_max, fetched_info.per_user_max),
+           SHOW_IFEN(fetched_info.has_per_user_max, fetched_info.per_user_max),
            SHOW_STATE(fetched_info.per_user_max));
     
     return 0;
@@ -1163,9 +1121,7 @@ static int do_passwd(const char * const file,
         fprintf(stderr, "Error with entering password - aborting\n");        
         return PW_ERROR_ENTER_PASSWD_PW_ERROR;
     }    
-    do_usermod(file, pwinfo);
-    
-    return 0;
+    return do_usermod(file, pwinfo);
 }
 
 static int do_mkdb(const char *dbfile, const char * const file)
@@ -1287,10 +1243,6 @@ int main(int argc, char *argv[])
 # endif
 #endif    
 
-#ifdef PROBE_RANDOM_AT_RUNTIME
-    pw_zrand_probe();
-#endif
-    
     pwinfo.pwd = NULL;
     pwinfo.gecos = NULL;
     pwinfo.home = NULL;
@@ -1326,8 +1278,8 @@ int main(int argc, char *argv[])
     }
     filter_pw_line_sep(pwinfo.login);
     while ((fodder =
-	    getopt(argc, argv, 
-		   "c:d:D:f:F:g:hi:I:mn:N:q:Q:r:R:t:T:u:y:z:")) != -1) {
+            getopt(argc, argv, 
+                   "c:d:D:f:F:g:hi:I:mn:N:q:Q:r:R:t:T:u:y:z:")) != -1) {
         switch(fodder) {
         case 'c' : {
             if ((pwinfo.gecos = strdup(optarg)) == NULL) {
@@ -1562,9 +1514,9 @@ int main(int argc, char *argv[])
             ret |= do_mkdb(dbfile, file);
         }        
     } else if (strcasecmp(action, "passwd") == 0) {
-        do_passwd(file, &pwinfo);
+        ret = do_passwd(file, &pwinfo);
         if (with_mkdb != 0) {
-            do_mkdb(dbfile, file);
+            ret |= do_mkdb(dbfile, file);
         }        
     } else if (strcasecmp(action, "show") == 0) {
         ret = do_show(file, &pwinfo);
