@@ -2,6 +2,7 @@
 
 #include "ftpd.h"
 #include "quotas.h"
+#include "safe_rw.h"
 
 #ifndef HAVE_GETOPT_LONG
 # include "bsd-getopt_long.h"
@@ -73,6 +74,8 @@ static int traversal(const char * const s)
     Node *nodes_pnt = nodes;
     size_t nodes_cnt = nodes_size;
     int fd;
+    char *buf = NULL;
+    size_t sizeof_buf = (size_t) 0U;
 
     if ((fd = open(s, O_RDONLY | O_DIRECTORY)) == -1) {
         if (errno != EACCES) {
@@ -117,7 +120,8 @@ static int traversal(const char * const s)
         nodes = new_nodes;
     }
     {
-        Node * const node = (Node *) (((unsigned char *) nodes) + nodes_size);
+        Node * const node =
+            (Node *) (void *) (((unsigned char *) nodes) + nodes_size);
 
         node->inode = st.st_ino;
         node->device = st.st_dev;
@@ -128,9 +132,8 @@ static int traversal(const char * const s)
     }
     slen = strlen(s) + (size_t) 2U;
     while ((de = readdir(d)) != NULL) {
-        char *alloca_buf;
-        size_t sizeof_buf;
-
+        size_t wanted_sizeof_buf;
+        
         if ((de->d_name[0] == '.' && de->d_name[1] == 0) ||
             (de->d_name[0] == '.' && de->d_name[1] == '.' &&
              de->d_name[2] == 0)) {
@@ -138,15 +141,18 @@ static int traversal(const char * const s)
         }
         if (strcmp(de->d_name, QUOTA_FILE) == 0) {
             continue;
+        }        
+        wanted_sizeof_buf = slen + strlen(de->d_name);
+        if (wanted_sizeof_buf > sizeof_buf) {
+            if ((buf = realloc(buf, wanted_sizeof_buf)) == NULL) {
+                oom();
+            }
+            sizeof_buf = wanted_sizeof_buf;
         }
-        sizeof_buf = slen + strlen(de->d_name);
-        if ((alloca_buf = ALLOCA(sizeof_buf)) == NULL) {
-            continue;
-        }
-        snprintf(alloca_buf, sizeof_buf, "%s/%s", s, de->d_name);
-        if (stat(alloca_buf, &st) == 0) {
+        snprintf(buf, sizeof_buf, "%s/%s", s, de->d_name);
+        if (stat(buf, &st) == 0) {
             if (S_ISDIR(st.st_mode)) {
-                if (traversal(alloca_buf) == 0) {
+                if (traversal(buf) == 0) {
                     total_files++;
                 }
             } else if (S_ISREG(st.st_mode)) {
@@ -154,8 +160,8 @@ static int traversal(const char * const s)
                 total_files++;
             }
         }
-        ALLOCA_FREE(alloca_buf);
     }
+    free(buf);    
     closedir(d);
 
     return 0;
@@ -220,7 +226,6 @@ static int writequota(const char * const quota_file)
     int fd;
     struct flock lock;
     ssize_t towrite;
-    ssize_t written;
     struct stat st;
     char buf[84];
     const char *bufpnt = buf;
@@ -256,24 +261,7 @@ static int writequota(const char * const quota_file)
         goto bye;
     }
     towrite = (ssize_t) strlen(buf);
-    while (towrite > (ssize_t) 0) {
-        for (;;) {
-            if ((written = write(fd, bufpnt,
-                                 (size_t) towrite)) <= (ssize_t) 0) {
-                if (written == (ssize_t) 0 ||
-                    (errno != EAGAIN && errno != EINTR)) {
-                    (void) ftruncate(fd, (off_t) 0);
-                    goto bye;
-                } else {
-                    continue;
-                }
-            }
-            break;
-        }
-        bufpnt += written;
-        towrite -=written;
-    }
-    err = 0;
+    err = - (safe_write(fd, bufpnt, towrite, -1) != (ssize_t) towrite);
     bye:
     lock.l_type = F_UNLCK;
     while (fcntl(fd, F_SETLK, &lock) < 0 && errno == EINTR);
